package com.ruoyi.hezhi.service;

import com.ruoyi.hezhi.domain.TbContinuingEducationClass;

import java.util.List;
import java.util.Map;

/**
 * 继续教育分类Service接口
 *
 * @author ruoyi
 * @date 2024-10-23
 */
public interface ITbContinuingEducationClassService
{
    /**
     * 查询继续教育分类
     *
     * @param continuingEducationClassId 继续教育分类主键
     * @return 继续教育分类
     */
    public TbContinuingEducationClass selectTbContinuingEducationClassByContinuingEducationClassId(Long continuingEducationClassId);

    /**
     * 查询继续教育分类列表
     *
     * @param tbContinuingEducationClass 继续教育分类
     * @return 继续教育分类集合
     */
    public List<TbContinuingEducationClass> selectTbContinuingEducationClassList(TbContinuingEducationClass tbContinuingEducationClass);

    /**
     * 查询继续教育分类列表
     *
     * @return 继续教育分类集合
     */
    public List<TbContinuingEducationClass> getAllContinuingEducationClassList();

    /**
     * 新增继续教育分类
     *
     * @param tbContinuingEducationClass 继续教育分类
     * @return 结果
     */
    public int insertTbContinuingEducationClass(TbContinuingEducationClass tbContinuingEducationClass);

    /**
     * 修改继续教育分类
     *
     * @param tbContinuingEducationClass 继续教育分类
     * @return 结果
     */
    public int updateTbContinuingEducationClass(TbContinuingEducationClass tbContinuingEducationClass);

    /**
     * 批量删除继续教育分类
     *
     * @param continuingEducationClassIds 需要删除的继续教育分类主键集合
     * @return 结果
     */
    public int deleteTbContinuingEducationClassByContinuingEducationClassIds(Long[] continuingEducationClassIds);

    /**
     * 删除继续教育分类信息
     *
     * @param continuingEducationClassId 继续教育分类主键
     * @return 结果
     */
    public int deleteTbContinuingEducationClassByContinuingEducationClassId(Long continuingEducationClassId);

    /**
     * 继续教育分类列表
     *
     * @param params 参数
     * @return 继续教育分类列表
     */
    public List<Map<String, Object>> getContinuingEducationClassMapList(Map<String, Object> params);

    /**
     * 继续教育列表
     *
     * @param params 参数
     * @return 继续教育列表
     */
    public List<Map<String, Object>> getContinuingEducationList(Map<String, Object> params);
}
